 Reahl is a web application framework that allows a Python programmer to work in
 terms of useful abstractions - using a single programming language.

 Reahl-browsertools provides an interface to Selenium WebDriver that simplifies tests that deal with ajax.
 It also includes programmatically composable XPaths that are easy to read in code.
